==> rcr-1.0.0-rc2.tar.gz: rcr/src/Commands/Drush9Commands.php <==
<?php

namespace Drupal\rcr\Commands;

use Drush\Commands\DrushCommands;
use SimpleXMLElement;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteBuilderInterface;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
class Drush9Commands extends DrushCommands {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The router builder.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  private $routeBuilder;

  /**
   * Constructs a new InvocationMethodServiceManager object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $route_builder
   *   The router builder.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RouteBuilderInterface $route_builder) {
    $this->configFactory = $config_factory;
    $this->routeBuilder = $route_builder;
  }

  /**
   * Get current rates.
   *
   * @command rcr:getrates
   * @aliases rcr-getrates
   * @usage rcr:getrates
   */
  public function getrates() {
    $config = $this->configFactory->getEditable('rcr.settings');
    $nowStr = date('d.m.Y', time());
    $dataxml = file_get_contents('https://www.cbr.ru/scripts/XML_daily.asp?date_req=' . $nowStr);
    if ($dataxml !== FALSE) {
      $xml = new SimpleXMLElement($dataxml);
      if (!empty($xml->Valute)) {
        foreach ($xml->Valute as $v) {
          if ($v->CharCode == 'USD') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $config->set('usd', round($replace_comma, 2))->save();
            $this->output()->writeln('USD rate was saved');
          }
          if ($v->CharCode == 'EUR') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $config->set('eur', round($replace_comma, 2))->save();
            $this->output()->writeln('EUR rate was saved');
          }
        }
      }
      $this->routeBuilder->rebuild();
    }
    else {
      $this->output()->writeln('Can not get current rates from www.cbr.ru');
    }
  }

}

==> rcr-1.0.2.tar.gz: rcr/src/Commands/Drush9Commands.php <==
<?php

namespace Drupal\rcr\Commands;

use Drush\Commands\DrushCommands;
use SimpleXMLElement;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
class Drush9Commands extends DrushCommands {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new InvocationMethodServiceManager object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Get current rates.
   *
   * @command rcr:getrates
   * @aliases rcr-getrates
   * @usage rcr:getrates
   */
  public function getrates() {
    $config = $this->configFactory->getEditable('rcr.settings');
    $nowStr = date('d.m.Y', time());
    $dataxml = file_get_contents('https://www.cbr.ru/scripts/XML_daily.asp?date_req=' . $nowStr);
    if ($dataxml !== FALSE) {
      $xml = new SimpleXMLElement($dataxml);
      if (!empty($xml->Valute)) {
        foreach ($xml->Valute as $v) {
          if ($v->CharCode == 'USD') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $config->set('usd', round($replace_comma, 2))->save();
            $this->output()->writeln('USD rate was saved');
          }
          if ($v->CharCode == 'EUR') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $config->set('eur', round($replace_comma, 2))->save();
            $this->output()->writeln('EUR rate was saved');
          }
        }
      }
    }
    else {
      $this->output()->writeln('Can not get current rates from www.cbr.ru');
    }
  }

}
